Installation
============

Requirements
------------

- Python 3.4+
- Works on Linux, Windows, Mac OSX, BSD

Install with pip
----------------

The quick way:

.. code-block:: bash

   > pip install parade

